Brightway2 regionalized LCA
===========================

This package provides a regionalized LCA calculations for the `Brightway2 life cycle assessment framework <https://brightwaylca.org>`_. `Online documentation <https://brightway2-regional.readthedocs.io/en/latest/>`_ is available, and the source code is hosted on `Bitucket <https://bitbucket.org/cmutel/brightway2-regional>`_.
